@@ -1,5 +1,6 @@
 from . import experimental, federation
 from .arguments import argument
+from .auto import auto
 from .custom_scalar import scalar
 from .directive import directive
 from .enum import enum
@@ -11,6 +12,7 @@ from .permission import BasePermission
 from .private import Private
 from .scalars import ID
 from .schema import Schema
+from .schema_directive import schema_directive
 from .union import union
 
 
@@ -23,6 +25,7 @@ __all__ = [
     "Schema",
     "argument",
     "directive",
+    "schema_directive",
     "enum",
     "federation",
     "field",
@@ -33,4 +36,5 @@ __all__ = [
     "subscription",
     "type",
     "union",
+    "auto",
 ]
