@@ -1,18 +1,30 @@
 import dataclasses
-from typing import Any, Dict, List, Optional
+from typing import TYPE_CHECKING, Any, Dict, List, Optional, Tuple, Type
 
-from graphql import ExecutionResult as GraphQLExecutionResult
+from graphql import (
+    ASTValidationRule,
+    ExecutionResult as GraphQLExecutionResult,
+    specified_rules,
+)
 from graphql.error.graphql_error import GraphQLError
 from graphql.language import DocumentNode
 
 
+if TYPE_CHECKING:
+    from strawberry.schema import Schema
+
+
 @dataclasses.dataclass
 class ExecutionContext:
     query: str
+    schema: "Schema"
     context: Any = None
     variables: Optional[Dict[str, Any]] = None
     operation_name: Optional[str] = None
     root_value: Optional[Any] = None
+    validation_rules: Tuple[Type[ASTValidationRule], ...] = dataclasses.field(
+        default_factory=lambda: tuple(specified_rules)
+    )
 
     # Values that get populated during the GraphQL execution so that they can be
     # accessed by extensions
